clear all
set more off
set scheme plotplainblind

********************************************************************************
*    File Paths
********************************************************************************
* Open as project to ensure filepaths work

global code "Code"
global data "Data"
global tables "Tables"
global figures "Figures"




********************************************************************************
*    Variable Declaration
********************************************************************************

global limit_year "keep if year >= 2016"
global limit_military "keep if military != 1"


//Fixed effects/Cluster
	// month-year fixed effects
		global time_fe mo_yr
		global time_lab "month-year"
	// two-way cluster on inmate and clinician
		global clust inmate_id clin_id

// Outcomes
	// First stage outcome
		global fs_out mh_court
	// Outcomes of interest
		global recid_outcomes los sa_hazard sa_los recid365 recid_18mo recid_2yr
		global outcomes_18_19 los sa_hazard sa_los recid365

// Demographics for propensity scores -- excludes white category
	local demogs asian black race_other hispanic male age num_priors
	// Demographics for 2018-2019 subsample analysis
		local full_demogs asian black race_other hispanic male age num_priors hospitalization takenmedications tcu_ever
	// Sets Table 1 variable order
		global tab_1_varlist mh_score_1 mh_score_2 mh_score_3 mh_score_4 $outcomes white `demogs' clin_male clin_white clin_black clin_hisp


// Set file list:
	#delimit ;
	local filelist  
		"02_create_instrument.do" 
		"03_data_exploration.do" 
		"04_instrument_validation.do"
		"05_analysis.do"
		;
	#delimit cr




********************************************************************************
*    Run analyses
********************************************************************************

*****************************************************
****************    Full Dataset     ****************
*****************************************************

***************************
* Misdemeanors
***************************
* Recid misdemeanors
	// set file label
		global filelab "mis"
	// set first stage label
		global fs_lab "Moderate/Severe (Misdemeanors)"
	// set primary outcomes
		global outcomes $recid_outcomes
	// set demographics
		global demogs `demogs'
	// limit the sample
		global limit_sample "keep if felony == 0"
	
	
	// loop through analysis files
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}

	
***************************
* Felonies
***************************
* Recid felonies
	// file label
		global filelab "fel"
	// first stage label
		global fs_lab "Moderate/Severe (Felonies)"
	// set primary outcomes
		global outcomes $recid_outcomes
		
	// set demographics
		global demogs `demogs'
	
	global limit_sample "keep if felony == 1"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}
	


*****************************************************
******    Heterogeneity by Race/Ethnicity      ******
*****************************************************
		
***************************
* Race and Misdemeanors
***************************
* Recid misdemeanors
	// file label
		global filelab "mis_black"
	// first stage label
		global fs_lab "Moderate/Severe for Black Individuals (Misdemeanors)"
	// set primary outcomes
		global outcomes $recid_outcomes
	// exclude demographics variables that are not relevant to subsample
		local exclude_list asian black race_other
		global demogs : list local(demogs) - local(exclude_list)
	
	global limit_sample "keep if felony == 0 & black == 1"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}
		
		
	
***************************
* Race and Felonies
***************************
* Recid felonies
	// file label
		global filelab "fel_black"
	// first stage label
		global fs_lab "Moderate/Severe for Black Individuals (Felonies)"
	// set primary outcomes
		global outcomes $recid_outcomes
	// exclude demographics variables that are not relevant to subsample
		local exclude_list asian black race_other
		global demogs : list local(demogs) - local(exclude_list)
	
	global limit_sample "keep if felony == 1 & black == 1"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}

	
	
	
***************************
* Race and Misdemeanors
***************************
* Recid misdemeanors
	// file label
		global filelab "mis_white"
	// first stage label
		global fs_lab "Moderate/Severe for White Individuals (Misdemeanors)"
	// set primary outcomes
		global outcomes $recid_outcomes
	// exclude demographics variables that are not relevant to subsample
		local exclude_list asian black race_other
		global demogs : list local(demogs) - local(exclude_list)
	
	global limit_sample "keep if felony == 0 & white == 1"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}
		
		
	
***************************
* Race and Felonies
***************************
* Recid felonies
	// file label
		global filelab "fel_white"
	// first stage label
		global fs_lab "Moderate/Severe for White Individuals (Felonies)"
	// set primary outcomes
		global outcomes $recid_outcomes
	// exclude demographics variables that are not relevant to subsample
		local exclude_list asian black race_other
		global demogs : list local(demogs) - local(exclude_list)
	
	global limit_sample "keep if felony == 1 & white == 1"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}
		
	
	
		
***************************
* Hispanic and Misdemeanors
***************************

* Recid misdemeanors
	// file label
		global filelab "mis_hisp"
	// first stage label
		global fs_lab "Moderate/Severe for Hispanic Individuals (Misdemeanors)"
	// set primary outcomes
		global outcomes $recid_outcomes
	// exclude demographics variables that are not relevant to subsample
		local exclude_list hispanic
		global demogs : list local(demogs) - local(exclude_list)
		
	global limit_sample "keep if felony == 0 & hispanic == 1"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}

	
		
	
***************************
* Hispanic and Felonies
***************************
* Recid felonies
	// file label
		global filelab "fel_hisp"
	// first stage label
		global fs_lab "Moderate/Severe for Hispanic Individuals (Felonies)"
	// set primary outcomes
		global outcomes $recid_outcomes
	// exclude demographics variables that are not relevant to subsample
		local exclude_list hispanic
		global demogs : list local(demogs) - local(exclude_list)
	
	global limit_sample "keep if felony == 1 & hispanic == 1"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}
	
	


*****************************************************
************     Mild/Moderate Only      ************
*****************************************************

***************************
* 1s/2s as Misdemeanors
***************************

	
* Recid misdemeanors
	// file label
		global filelab "mis_complier"
	// first stage label
		global fs_lab "Moderate for Individuals Assessed as Mild/Moderate (Misdemeanors)"
	// set primary outcomes
		global outcomes $recid_outcomes
	// set demographics
		global demogs `demogs'
	
	global limit_sample "keep if felony == 0 & inlist(mh_score, 1, 2)"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}


***************************
* 1s/2s as Felonies
***************************
* Recid felonies
	// file label
		global filelab "fel_complier"
	// first stage label
		global fs_lab "Moderate for Individuals Assessed as Mild/Moderate (Felonies)"
	// set primary outcomes
		global outcomes $recid_outcomes
	// set demographics
		global demogs `demogs'
	
	global limit_sample "keep if felony == 1 & inlist(mh_score, 1, 2)"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}


*****************************************************
****     Only Clinicians with large caseload     ****
*****************************************************

***************************
* Caseload >= 500 as Misdemeanors
***************************

	
* Recid misdemeanors
	// file label
		global filelab "mis_over500cases"
	// first stage label
		global fs_lab "Moderate/Severe by Clinicians with At Least 500 Cases (Misdemeanors)"
	// set primary outcomes
		global outcomes $recid_outcomes
	
	// set demographics
		global demogs `demogs'
	
	global limit_sample "keep if felony == 0 & tot_cases >= 500"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}


***************************
* Caseload >= 500 as Felonies
***************************
* Recid felonies
	// file label
		global filelab "fel_over500cases"
	// first stage label
		global fs_lab "Moderate/Severe by Clinicians with At Least 500 Cases (Felonies)"
	// set primary outcomes
		global outcomes $recid_outcomes
		
	// set demographics
		global demogs `demogs'
	
	global limit_sample "keep if felony == 1 & tot_cases >= 500"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}





*****************************************************
************     2018-2019 Subsample     ************
*****************************************************

***************************
* 2018-2019 Misdemeanors
***************************
* Recid misdemeanors
	// file label
		global filelab "mis_yr_18_19"
	// first stage label
		global fs_lab "Moderate/Severe (Misdemeanors, 2018-2019)"
	// set primary outcomes
		global outcomes $outcomes_18_19
	// set demographics
		global demogs `full_demogs'
	
	global limit_sample "keep if felony == 0 & ((year == 2018 & month > 7) | (year == 2019))"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}

	
***************************
* 2018-2019 Felonies
***************************
* Recid felonies
	// file label
		global filelab "fel_yr_18_19"
	// first stage label
		global fs_lab "Moderate/Severe (Felonies, 2018-2019)"
	// set primary outcomes
		global outcomes $outcomes_18_19
	// set demographics
		global demogs `full_demogs'
	
	global limit_sample "keep if felony == 1 & ((year == 2018 & month > 7) | (year == 2019))"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}

	
	
*****************************************************
***********     2018-2019 No Drug Use     ***********
*****************************************************

***************************
* 2018-2019 No TCU Misdemeanors
***************************
* Recid misdemeanors
	// file label
		global filelab "mis_no_tcu_18_19"
	// first stage label
		global fs_lab "Moderate/Severe for Individuals with No Drug/Alcohol Use Reported (Misdemeanors, 2018-2019)"
	// set primary outcomes
		global outcomes $outcomes_18_19
	// set demographics
		global demogs `full_demogs'
	
	global limit_sample "keep if felony == 0 & (tcu_ever == 0 | missing(tcu_ever)) & ((year == 2018 & month > 7) | (year == 2019))"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}

	
***************************
* 2018-2019 No TCU Felonies
***************************
* Recid felonies
	// file label
		global filelab "fel_no_tcu_18_19"
	// first stage label
		global fs_lab "Moderate/Severe for Individuals with No Drug/Alcohol Use Reported (Felonies, 2018-2019)"
	// set primary outcomes
		global outcomes $outcomes_18_19
	// set demographics
		global demogs `full_demogs'
	
	global limit_sample "keep if felony == 1 & (tcu_ever == 0 | missing(tcu_ever)) & ((year == 2018 & month > 7) | (year == 2019))"
		
	foreach dofile in `filelist' {
		do "$code/`dofile'"
	}
	
	